@@ -1,9 +1,46 @@
 import os
 
+# windows仅支持8种颜色
+
 os.system("")  # print颜色开启(玄学)
 # 打印开关
 isPrint = True
 
+# 定义颜色，方便简打
+_color_black = "black"
+_color_red = "red"
+_color_green = "green"
+_color_yellow = "yellow"
+_color_blue = "blue"
+_color_purplered = "purple-red"
+_color_cyanine = "cyanine"
+_color_white = "white"
+_color_default = "default"
+
+_background_black = "black"
+_background_red = "red"
+_background_green = "green"
+_background_yellow = "yellow"
+_background_blue = "blue"
+_background_purplered = "purple-red"
+_background_cyanine = "cyanine"
+_background_white = "white"
+_background_default = "default"
+
+_effect_default = "default"
+_effect_highlight = "highlight"
+_effect_underline = "underline"
+_effect_flash = "flash"
+_effect_backwhite = "backwhite"
+_effect_unshow = "unshow"
+
+_Type_error = "error"
+_Type_warning = "warning"
+_Type_success = "success"
+_Type_data = "data"
+_Type_system = "system"
+_Type_normal = "normal"
+
 
 def set_isPrint(is_print=True):
     global isPrint
@@ -49,7 +86,7 @@ _effect = {
 }
 # 类型：简化设置
 _Type = {
-    "error": ["red", "default", "default"],
+    "error": ["red", "underline", "default"],
     "warning": ["yellow", "default", "default"],
     "success": ["green", "default", "default"],
     "data": ["blue", "default", "default"],
@@ -60,7 +97,7 @@ _Type = {
 
 # 打印函数（带颜色和输出控制）
 def printf(
-        value,
+        *value,
         color="default",
         effect="default",
         background="default",
@@ -92,12 +129,10 @@ def printf(
             print("\033[31m打印函数背景色参数错误\033[0m")
             background = "default"
     if isPrint or control:
-        print(
-            "\033[%s;%s%sm%s\033[0m"
-            % (_effect[effect], _background[background], _color[color], value),
-            sep=sep, end=end, file=file, flush=flush
-        )
+        print("\033[%s;%s%sm" % (_effect[effect], _background[background], _color[color]), sep="", end="")
+        print(*value, sep=sep, end="\033[0m" + end, file=file, flush=flush)
 
 
 if __name__ == '__main__':
-    printf("thgttr", color="red")
+    printf("thgttr", "sdsdds", Type=_Type_error)
+    printf("ssdd", Type=_Type_system)
